@@ -8,22 +8,21 @@ class Logger:
         if config_dict is not None:
             self.config_dict = config_dict
         else:
-            self.config_dict = {
-                "formatters": {
-                    "f": {
-                        {'format': "%(levelname)s: %(message)s"}
-                    }
+            self.config_dict = dict(
+                formatters={
+                    'f': {'format':
+                          '%(levelname)s: %(message)s'}
                 },
-                "handlers": {
-                    'h': {
-                        {'class': 'logging.StreamHandler',
-                            'formatter': "f", "level": 10}
-                    }
+                handlers={
+                    'h': {'class': 'logging.StreamHandler',
+                          'formatter': 'f',
+                          'level': logging.DEBUG}
                 },
-                "root": {
-                    "handlers": ['h'], "level": 10
-                }
-            }
+                root={
+                    'handlers': ['h'],
+                    'level': logging.DEBUG,
+                },
+            )
 
         dictConfig(self.config_dict)
 
